@@ -45,14 +45,23 @@
 #' @seealso grouped_lm, grouped_glmer
 #'
 #' @examples
-#'
+#' 
+#' # to get tidy output
 #' groupedstats::grouped_glm(
-#'   data = ggstatsplot::Titanic_full,
+#'   data = groupedstats::Titanic_full,
 #'   formula = Survived ~ Sex,
 #'   grouping.vars = Class,
 #'   family = stats::binomial(link = "logit")
 #' )
-#'
+#' 
+#' # to get glance output
+#' groupedstats::grouped_glm(
+#'   data = groupedstats::Titanic_full,
+#'   formula = Survived ~ Sex,
+#'   grouping.vars = Class,
+#'   family = stats::binomial(link = "logit"),
+#'   output = "glance"
+#' )
 #' @export
 #'
 
@@ -74,9 +83,11 @@ grouped_glm <- function(data,
     }
 
   # getting the dataframe ready
-  df <- dplyr::select(.data = data,
-                      !!!grouping.vars,
-                      dplyr::everything()) %>%
+  df <- dplyr::select(
+    .data = data,
+    !!!grouping.vars,
+    dplyr::everything()
+  ) %>%
     dplyr::group_by(.data = ., !!!grouping.vars) %>%
     tidyr::nest(data = .) %>%
     dplyr::ungroup(x = .)
@@ -86,18 +97,18 @@ grouped_glm <- function(data,
   # custom function to run tidy operation on every element of list column
   fnlisted <-
     function(list.col,
-             formula,
-             family,
-             output,
-             quick,
-             exponentiate) {
+                 formula,
+                 family,
+                 output,
+                 quick,
+                 exponentiate) {
       if (output == "tidy") {
         # dataframe with results from glm
         results_df <-
           list.col %>% # tidying up the output with broom
           purrr::map_dfr(
             .x = .,
-            .f = ~ broom::tidy(
+            .f = ~broom::tidy(
               x = stats::glm(
                 formula = stats::as.formula(formula),
                 data = (.),
@@ -118,7 +129,7 @@ grouped_glm <- function(data,
           list.col %>% # tidying up the output with broom
           purrr::map_dfr(
             .x = .,
-            .f = ~ broom::glance(
+            .f = ~broom::glance(
               x = stats::glm(
                 formula = stats::as.formula(formula),
                 data = (.),
@@ -139,7 +150,7 @@ grouped_glm <- function(data,
 
   # converting the original dataframe to have a grouping variable column
   df %<>%
-    tibble::rownames_to_column(df = ., var = "..group")
+    tibble::rownames_to_column(., var = "..group")
 
   combined_df <- purrr::pmap(
     .l = list(
@@ -160,7 +171,7 @@ grouped_glm <- function(data,
   # add a column with significance labels if p-values are present
   if ("p.value" %in% names(combined_df)) {
     combined_df %<>%
-      ggstatsplot:::signif_column(data = ., p = p.value)
+      signif_column(data = ., p = p.value)
   }
 
   return(combined_df)
