@@ -40,13 +40,14 @@
 #' @seealso grouped_lm
 #'
 #' @examples
-#'
+#' 
 #' # in case of just one grouping variable
-#' groupedstats::grouped_slr(data = iris,
-#' dep.vars = c(Sepal.Length, Petal.Length),
-#' indep.vars = c(Sepal.Width, Petal.Width),
-#' grouping.vars = Species)
-#'
+#' groupedstats::grouped_slr(
+#'   data = iris,
+#'   dep.vars = c(Sepal.Length, Petal.Length),
+#'   indep.vars = c(Sepal.Width, Petal.Width),
+#'   grouping.vars = Species
+#' )
 #' @export
 #'
 
@@ -157,7 +158,7 @@ grouped_slr <- function(data,
 
   # converting the original dataframe to have a grouping variable column
   df %<>%
-    tibble::rownames_to_column(df = ., var = "group")
+    tibble::rownames_to_column(., var = "group")
 
   # running custom function for each element of the created list column
   df_lm <- purrr::pmap(
