@@ -3,7 +3,7 @@
 #' @aliases signif_column
 #' @author Indrajeet Patil
 #' @description This function will add a new column to a dataframe containing
-#'   p-values
+#'   *p*-values
 #' @return Returns the originally entered object (either a vector or a
 #'   dataframe) in tibble format with an additional column corresponding to
 #'   statistical significance.
@@ -12,7 +12,15 @@
 #'   be taken.
 #' @param p The column containing p-values.
 #'
-#'
+#' @importFrom dplyr group_by
+#' @importFrom dplyr summarize
+#' @importFrom dplyr n
+#' @importFrom dplyr arrange
+#' @importFrom dplyr mutate
+#' @importFrom dplyr mutate_at
+#' @importFrom dplyr mutate_if
+#' @importFrom magrittr "%<>%"
+#' @importFrom magrittr "%>%"
 #' @importFrom broom tidy
 #' @importFrom crayon red
 #' @importFrom crayon blue
@@ -20,21 +28,40 @@
 #' @importFrom stats lm
 #' @importFrom tibble as_data_frame
 #'
-#' @keywords internal
+#' @family helper_stats
 #'
-#' @note This is a helper function used internally in the package and not
-#'   exported. In case you want to use it, you can do so by
-#'   `groupedstats:::signif_column`. Note that it is `:::` and not `::`.
+#' @examples
 #'
+#' # vector as input
+#' groupedstats::signif_column(p = c(0.05, 0.1, 1, 0.00001, 0.001, 0.01))
+#'
+#' # dataframe as input
+#' # preparing a newdataframe
+#' df <- cbind.data.frame(
+#'   x = 1:5,
+#'   y = 1,
+#'   p.value = c(0.1, 0.5, 0.00001, 0.05, 0.01)
+#' )
+#'
+#' groupedstats::signif_column(data = df, p = p.value)
+#'
+#' # numbers entered as characters are also tolerated
+#' groupedstats::signif_column(p = c("1", "0.1", "0.0002", "0.03", "0.65"))
+#' @export
 
+# function body
 signif_column <- function(data = NULL, p) {
-  # storing variable name to be assigned later
-  p_lab <- colnames(dplyr::select(
-    .data = data,
-    !!rlang::enquo(p)
-  ))
+
   # if dataframe is provided
   if (!is.null(data)) {
+
+    # storing variable name to be assigned later
+    p_lab <- colnames(dplyr::select(
+      .data = data,
+      !!rlang::enquo(p)
+    ))
+
+    # preparing dataframe
     df <-
       dplyr::select(
         .data = data,
@@ -43,17 +70,33 @@ signif_column <- function(data = NULL, p) {
         dplyr::everything()
       )
   } else {
+
     # if only vector is provided
     df <-
-      base::cbind.data.frame(p = p) # column corresponding to p-values
+      base::cbind.data.frame(p = p)
   }
 
-  # make sure the p-value column is numeric; if not, convert it to numeric and give a warning to the user
+  # make sure the p-value column is numeric; if not, convert it to numeric
   if (!is.numeric(df$p)) {
+
+    # display message about conversion
+    base::message(cat(
+      crayon::green("Note: "),
+      crayon::blue(
+        "The entered vector is of class",
+        crayon::yellow(class(df$p)[[1]]),
+        "; attempting to convert it to numeric."
+      ),
+      sep = ""
+    ))
+
+    # conversion
     df$p <- as.numeric(as.character(df$p))
   }
-  # add new significance column based on standard APA guidelines for describing different levels of significance
-  df <- df %>%
+
+  # add new significance column based on standard APA guidelines for describing
+  # different levels of significance
+  df %<>%
     dplyr::mutate(
       .data = .,
       significance = dplyr::case_when(
@@ -70,71 +113,23 @@ signif_column <- function(data = NULL, p) {
       )
     ) %>%
     tibble::as_data_frame(x = .) # convert to tibble dataframe
-  # change back from the generic p-value to the original name that was provided by the user for the p-value
+
+  # change back from the generic p-value to the original name that was provided
+  # by the user for the p-value
   if (!is.null(data)) {
+
     # reordering the dataframe
-    df <- df %>%
+    df %<>%
       dplyr::select(.data = ., -p, -significance, dplyr::everything())
+
     # renaming the p-value variable with the name provided by the user
     colnames(df)[which(names(df) == "p")] <- p_lab
   }
+
   # return the final tibble dataframe
   return(df)
 }
 
-
-#'
-#' @title Custom function for getting specified number of decimal places in
-#'   results for p-value
-#' @name specify_decimal_p
-#' @aliases specify_decimal_p
-#' @description Function to format an R object for pretty printing with a
-#'   specified (`k`) number of decimal places. The function also allows highly
-#'   significant p-values to be denoted as "p < 0.001" rather than "p = 0.000".
-#' @author Indrajeet Patil
-#'
-#' @param x A numeric variable.
-#' @param k Number of digits after decimal point (should be an integer).
-#' @param p.value Decides whether the number is a p-value (Default: `FALSE`).
-#'
-#' @return Formatted numeric values.
-#'
-#' @keywords internal
-#'
-#' @note This is a helper function used internally in the package and not
-#'   exported. In case you want to use it, you can do so by
-#'   `groupedstats:::specify_decimal_p`. Note that it is `:::` and not `::`.
-#'
-
-specify_decimal_p <- function(x,
-                              k = NULL,
-                              p.value = FALSE) {
-  # if the number of decimal places hasn't been specified, use the default of 3
-  if (is.null(k)) {
-    k <- 3
-  }
-  # formatting the output properly
-  output <-
-    base::trimws(
-      x = base::format(
-        x = base::round(x = x, digits = k),
-        nsmall = k
-      ),
-      which = "both"
-    )
-  # if it's a p-value, then format it properly
-  if (isTRUE(p.value)) {
-    # determing the class of output
-    if (output < 0.001) {
-      output <- "< 0.001"
-    }
-  }
-  # this will return a character
-  return(output)
-}
-
-
-#'
 #' @title Confidence intervals for partial eta-squared and omega-squared for
 #'   linear models.
 #' @name lm_effsize_ci
@@ -145,16 +140,18 @@ specify_decimal_p <- function(x,
 #' @return A dataframe with results from `stats::lm()` with partial eta-squared,
 #'   omega-squared, and bootstrapped confidence interval for the same.
 #'
-#' @param object The linear model object (can be of class `lm`, `aov`, or
+#' @param object The linear model object (can be of class `lm`, `aov`, `anova`, or
 #'   `aovlist`).
 #' @param effsize Character describing the effect size to be displayed: `"eta"`
 #'   (default) or `"omega"`.
 #' @param partial Logical that decides if partial eta-squared or omega-squared
-#'   are returned (Default: `TRUE`).
+#'   are returned (Default: `TRUE`). If `FALSE`, eta-squared or omega-squared
+#'   will be returned. Valid only for objects of class `lm`, `aov`, `anova`, or
+#'   `aovlist`.
 #' @param conf.level Numeric specifying Level of confidence for the confidence
 #'   interval (Default: `0.95`).
 #' @param nboot Number of bootstrap samples for confidence intervals for partial
-#'   eta-squared and omega-squared (Default: `1000`).
+#'   eta-squared and omega-squared (Default: `500`).
 #'
 #' @importFrom sjstats eta_sq
 #' @importFrom sjstats omega_sq
@@ -162,23 +159,9 @@ specify_decimal_p <- function(x,
 #' @importFrom stats na.omit
 #' @importFrom stats lm
 #' @importFrom tibble as_data_frame
-#' @importFrom tibble rownames_to_column
 #' @importFrom broom tidy
 #'
-#' @examples
-#'
-#' # lm object
-#' # lm_effsize_ci(object = stats::lm(formula = wt ~ am * cyl, data = mtcars),
-#' # effsize = "omega",
-#' # partial = TRUE)
-#'
-#' # aov object
-#' # lm_effsize_ci(object = stats::aov(formula = wt ~ am * cyl, data = mtcars),
-#' # effsize = "eta",
-#' # partial = FALSE)
-#'
-#' @keywords internal
-#'
+#' @export
 
 # defining the function body
 lm_effsize_ci <-
@@ -186,12 +169,13 @@ lm_effsize_ci <-
              effsize = "eta",
              partial = TRUE,
              conf.level = 0.95,
-             nboot = 1000) {
+             nboot = 500) {
+
     # based on the class, get the tidy output using broom
     if (class(object)[[1]] == "lm") {
       aov_df <-
         broom::tidy(stats::anova(object = object))
-    } else if (class(object)[[1]] == "aov") {
+    } else if (class(object)[[1]] %in% c("aov", "anova")) {
       aov_df <- broom::tidy(x = object)
     } else if (class(object)[[1]] == "aovlist") {
       aov_df <- broom::tidy(x = object) %>%
